import React, { ReactNode, ReactElement } from 'react';

interface HeaderProps {
    backgroundImageUrl?: string;
    backgroundImgAltText?: string;
    isAuthenticated: boolean;
    useSeoJsonData?: any | null;
    useHeadingJson?: any | null;
    children: ReactNode;
    brandName: string;
}
declare const HeaderSection: React.FC<HeaderProps>;

interface IBurgerMenuChildValues {
    label?: string;
    link?: string;
    children?: IBurgerMenuChildValues[];
    name?: string;
    action?: () => void;
    appUrl?: 'MainPortal' | 'QBPortal' | 'ResourcesPortal' | 'OuterDomain' | 'Action';
}
interface BurgerMenuProps {
    menuData: IBurgerMenuChildValues[];
    Name?: string;
    id?: string;
    LogoUrl?: string;
    changeAction: (status: boolean) => void;
    openTab: boolean | null;
    MainPortal?: string;
    QBPortal?: string;
    ResourcesPortal?: string;
    OuterDomain?: string;
}
declare const BurgerMenu: React.FC<BurgerMenuProps>;

interface LogoProps {
    title?: string;
    imageUrl?: string;
    link?: string;
    action?: () => void;
    state?: any;
    isLoading?: boolean;
}
declare const Logo: React.FC<LogoProps>;

type MenuItemLabel = 'Dashboard' | 'Notifications' | 'Messaging' | 'Appointments' | 'Circle of care' | 'Questionnaires' | 'Forms' | 'Carer dashboard' | 'User management' | 'Permission management' | 'Trust management' | 'Theme management' | 'ICB management' | 'Resource hub';
type MenuItemProps = {
    label: MenuItemLabel | string;
    to: string;
    action?: () => void;
    icon?: ReactElement;
    isHide?: boolean;
    appUrl?: 'MainPortal' | 'QBPortal' | 'ResourcesPortal' | 'OuterDomain' | 'Action';
};
interface MenuItem {
    label: string;
    link?: string;
    icon?: JSX.Element;
    action?: () => void;
    isActive: boolean;
    isHide: boolean;
    permissionKey?: any;
    module?: any;
    appUrl?: 'MainPortal' | 'QBPortal' | 'ResourcesPortal' | 'OuterDomain' | 'Action';
}
interface ITrustInfo {
    uuid: string;
    trustId?: string;
    trustInfo: {
        uuid?: string;
        trustCode: string;
        trustLogoUrl: string;
        trustName: string;
        trustUiTheme: string;
        trustRegional?: any;
    };
}
interface IUserInfo {
    openDialogID?: string | null;
    accessToken?: string | null;
    refreshToken?: string | null;
    _id?: string;
    uuid?: string;
    username?: string;
    firstName?: string;
    email?: string;
    mobileNumber?: string;
    profile_image?: string;
    nameCalled?: string;
    dob?: string;
    userType?: string;
    authenticatedApps?: any;
    smartDashboard?: any;
    gender?: string;
    loginType?: 'normal' | 'google' | 'nhs' | 'azure';
    maritalStatus?: string;
    ethnicity?: string;
    languagesSpoken?: string[];
    iNeedAnInterpreter?: boolean;
    enabledTrackers?: any;
    mobileOtp?: boolean;
    mailOtp?: boolean;
    role?: string;
    lastName?: string;
    createdAt?: string;
    userId?: any;
    userProfile?: any;
    resourcePreference?: any;
    isCarer?: boolean;
    isProxyUser?: boolean;
    trusts?: Array<ITrustInfo>;
    isCarerAndUser?: boolean;
    accessibility?: any;
    userSkin?: string;
    password?: string;
    trust_list?: Array<ITrustInfo>;
    mfaSetupComplete?: boolean;
    mfaBackupCodesAvailable?: number;
    nhsNumber?: string;
}
interface UserProfileInfo {
    userId: string;
    firstName: string;
    lastName: string;
    email: string;
    avatarUrl?: string;
}
interface IBurgerMenu {
    label: string;
    link?: string;
    children?: IBurgerMenu[];
    name?: string;
    action?: () => void;
    appUrl?: 'MainPortal' | 'QBPortal' | 'ResourcesPortal' | 'OuterDomain' | 'Action';
}

interface PrimaryNavProps {
    navItems: MenuItem[];
    userInfo?: any;
    MainPortal?: string;
    QBPortal?: string;
    ResourcesPortal?: string;
    OuterDomain?: string;
}
declare const PrimaryNav: React.FC<PrimaryNavProps>;

interface MenuProps {
    menuItems: MenuItemProps[];
    changeAction: (status: boolean) => void;
    openTab: boolean;
    MainPortal?: string;
    QBPortal?: string;
    ResourcesPortal?: string;
    OuterDomain?: string;
}
declare const Menu: React.FC<MenuProps>;

interface NotificationProps {
    dropStatus: boolean;
    openNotify: (status: boolean) => void;
    goNotifications: () => void;
    totalNotifications: number;
    children: ReactNode;
}
declare const NavNotification: React.FC<NotificationProps>;

interface RecordStatusProps {
    label: string;
    hide?: boolean;
    button?: string;
    btn_function?: (e: any) => void;
}
declare const RecordStatus: React.FC<RecordStatusProps>;

interface AccountProps {
    proxyUsers?: any[];
    userInfo: IUserInfo | any;
    menuItems: MenuItemProps[] | any;
    openTab: boolean | null;
    changeAction: (status: boolean) => void;
    MainPortal?: string;
    QBPortal?: string;
    ResourcesPortal?: string;
    OuterDomain?: string;
}
declare const Account: React.FC<AccountProps>;

interface TooltipProps {
    delay?: number;
    direction?: string;
    content: React.ReactNode;
    children: React.ReactNode;
    className?: string;
}
declare const Tooltip: React.FC<TooltipProps>;

interface ButtonProps {
    text?: string;
    addClass?: string;
    btntype: 'submit' | 'button';
    disabled?: boolean;
    onClick?: any;
    showIcon?: boolean;
    onKeyDown?: any;
    iconPlaceholder?: any;
    ariaLive?: 'polite' | 'assertive';
    ariaexpanded?: boolean;
    showLoading?: boolean;
    children?: any;
    customButton?: boolean;
    showLabel?: boolean;
    navigationValue?: string;
    ariaLabel?: string;
    ariaLabelledby?: string;
    btnId?: any;
    btnCatogery?: 'button' | 'toggle' | 'accordion';
    status?: boolean;
    btnName?: any;
    btnValue?: any;
    btnTitle?: any;
    btnStyle?: any;
    btnKey?: any;
}

interface LoaderSVGProps {
    status?: boolean;
}
declare const LoaderSVG: React.FC<LoaderSVGProps>;

interface BottomNavProps {
    navItems: MenuItem[];
    MainPortal?: string;
    QBPortal?: string;
    ResourcesPortal?: string;
    OuterDomain?: string;
}
declare const BottomNav: React.FC<BottomNavProps>;

declare const portalUrls: {
    outerDomainUrls: {};
    mainPortalUrls: {
        auth: {
            login: string;
            signup: string;
        };
        dashboard: {
            patient: string;
            default: string;
            carer: string;
            superadmin: string;
            madmin: string;
        };
        tracking: {
            index: string;
            goals: string;
            coping: string;
            diary: string;
            trackers: {
                index: string;
                dashboard: string;
                overview: string;
                sleep: string;
                mood: string;
                alcohol: string;
                pain: string;
                problem: string;
                smoking: string;
                bloodPressure: string;
                bmiWeight: string;
                temperature: string;
                period: string;
                headache: string;
                preheadache: string;
                exercise: string;
                dailySteps: string;
                weight: string;
                waist: string;
                diet: string;
                fluid: string;
            };
            fitbit: {
                fitbitSleep: string;
                fitbitStep: string;
                portal: string;
            };
            deviceTracker: {
                index: string;
                dashboard: string;
            };
        };
        profile: {
            index: string;
            aboutMe: {
                personalOverview: string;
                personalDetails: string;
                myBackground: string;
                myNeeds: string;
                viewRecord: string;
                consent: string;
                preferences: string;
                deactivateAccount: string;
                goals: string;
            };
            trusts: string;
            trustInvites: string;
            keyHealthInfo: string;
            myContacts: string;
        };
        settings: {
            index: string;
            accountSettings: string;
            trustManagement: string;
            trustInvites: string;
            viewRecord: string;
            consent: string;
            preferences: string;
            deactivateAccount: string;
            myProfessionalProfile: string;
            settings: string;
            globalSettings: string;
            moduleSettings: string;
            brandSettings: string;
        };
        theme: {
            index: string;
            themeSettings: string;
        };
        superadmin: {
            adminlist: string;
            adminnew: string;
        };
        carer: {
            accessHealth: string;
        };
        admin: {
            index: string;
            people: {
                myProfessionalProfile: string;
                directory: string;
                professionalCirclePatient: string;
                professionalCircleColleague: string;
            };
            settings: {
                settings: string;
            };
        };
        clinician: {
            notifications: string;
            people: {
                index: string;
                myProfessionalProfile: string;
                directory: string;
                professionalCirclePatient: string;
                professionalCircleColleague: string;
            };
            settings: {
                settings: string;
            };
        };
        caseLoad: {
            index: string;
            clinician: {
                clinicalCaseload: string;
                infoHealth: string;
                infoConnect: string;
                infoTracker: string;
                infoAbout: string;
            };
            admin: {
                teamCaseload: string;
                patientOverview: string;
                bestInterest: string;
                myClinicalCaseload: string;
            };
        };
        myhealth: {
            index: string;
            healthOverview: string;
            careJourney: string;
            carePlans: string;
            advanceCarePlan: string;
            viewCarePlan: string;
            aboutme: string;
            currentHealth: {
                diagnoses: string;
                allergies: string;
                medications: string;
            };
            documents: string;
            documentUpload: string;
            documentsUnread: string;
            documentsRead: string;
            documentsArchive: string;
            documentView: string;
            documentsLetter: string;
            documentsLetterView: string;
            lifeStyle: {
                myHealthFactors: string;
                hobbiesActivities: string;
            };
            healthHistory: string;
            diagnosisHistory: string;
            medicationHistory: string;
            allergiesHistory: string;
            encounters: string;
        };
        circle: {
            index: string;
            connectOverview: string;
            serviceUser: {
                myCarers: string;
                myPeers: string;
                myClinicians: string;
                myAdmins: string;
                infoHealth: string;
                infoTracker: string;
                infoConnect: string;
            };
            admin: {
                new: string;
                careTeam: string;
                clinicians: string;
                patients: string;
            };
            clinician: {
                patients: string;
                colleague: string;
                messages: string;
                patientsInvite: string;
                info: string;
                infoHealth: string;
                infoTracker: string;
                infoConnect: string;
            };
            messages: string;
            requestRecieved: string;
            requestSent: string;
        };
        questionnaires: {
            clinician: {
                index: string;
                dashboard: string;
                formsQuestionnaires: string;
                formApprovals: string;
                responses: string;
            };
        };
        resources: {
            index: string;
            myResources: string;
            myResourcesAll: string;
            myResourcesSave: string;
            myResourcesRecommended: string;
            recommendedIndex: string;
            allResources: string;
            recommendedResources: string;
            apps: string;
            articles: string;
            events: string;
            videos: string;
            tips: string;
            usefulLinks: string;
            researchPapers: string;
            stories: string;
            patientLeafLets: string;
            openDialogSearch: string;
            healthAZ: string;
            hnaForms: string;
            hciLibrary: string;
            bereavementsupport: string;
            viewResource: string;
        };
        notifications: {
            index: string;
            overView: string;
            createNotification: string;
            editNotification: string;
            notificationsHistory: string;
            scheduledNotifications: string;
            templates: string;
            activityLog: string;
            patientNotifications: string;
            notificationPreferences: string;
            smsOverview: string;
            smsTemplate: string;
            addSms: string;
            smsTemplateAll: string;
            smsTemplateActive: string;
            smsTemplateInactive: string;
            smsTemplateArchived: string;
            createSmsTemplate: string;
            smsScheduled: string;
            smsViewScheduled: string;
            smsNotificationsHistory: string;
            smsNotificationsHistoryView: string;
        };
        appointment: {
            index: string;
            admin: {
                allClinicLocations: string;
                ClinicLocationsDetails: string;
                addClinic: string;
                editClinic: string;
                dashboard: string;
                allClinics: string;
                addClinicPage: string;
                allClinicsPatient: string;
                cliniciansGroups: string;
                vaccinationType: string;
                createVaccination: string;
                amendBooking: string;
                amendBookingConsultation: string;
                amendBookingVaccination: string;
                patients: string;
                diagnosisType: string;
                diagnosisTypeCreate: string;
                appointmentType: string;
                appointmentTypeCreate: string;
            };
            patient: {
                index: string;
                dashboard: string;
                upcomingAppointment: string;
                pastAppointment: string;
                cancelledAppointment: string;
                appointmentDetails: string;
                appointmentBooking: string;
                viewVaccinationBooking: string;
                rioReschedule: string;
            };
            clinician: {
                dashboard: string;
                newClinic: string;
                addClinic: string;
                requestDiagnosis: string;
                todaysClinic: string;
                upcomingClinic: string;
                pastClinic: string;
                patients: string;
                allAppointment: string;
            };
        };
        rbac: {
            index: string;
            superAdmin: {
                dashboard: string;
                overview: string;
                modules: string;
                userManagement: string;
                archivedUser: string;
                inactiveUser: string;
                inviteUser: string;
                permissionManagement: string;
                adminActiveUser: string;
                superAdminActiveUser: string;
                clinicianActiveUser: string;
                patientActiveUser: string;
                ClinicianPermissioManagement: string;
                superAdminPermissioManagement: string;
                PatientPermissionManagement: string;
                adminSubrolePermission: string;
                clinicianSubrolePermission: string;
                patientSubrolePermission: string;
                createSubrolePermission: string;
                userGroup: string;
                portalUsers: string;
                systemUsers: string;
                branding: string;
                termsAndPrivacy: string;
                subRoles: string;
                createSubroles: string;
                archiveUserInfo: string;
                deleteUserInfo: string;
            };
            mediwaveAdmin: {
                dashboard: string;
                modules: string;
                branding: string;
                regional: string;
                regionalAdd: string;
                Add: string;
                regionalManageModules: string;
                regionalManageInformation: string;
                regionalManageRoles: string;
                regionalManageRolesAdd: string;
                regionalManageAllUsers: string;
                regionalManageAllUsersAdd: string;
                emailConfiguration: string;
                serviceOverview: string;
                serviceManageInformation: string;
                serviceManageAllUsers: string;
                serviceManageAllUsersAdd: string;
                serviceAdd: string;
                trusts: string;
                trustsDetails: string;
                trustsManage: string;
                trustAdd: string;
                trustsUrgentHelp: string;
            };
            regionalAdmin: {
                index: string;
                regional: string;
                dashboard: string;
                regionalManageModules: string;
                regionalManageInformation: string;
                regionalManageRoles: string;
                regionalManageRolesAdd: string;
                regionalManageAllUsers: string;
                regionalManageAllUsersAdd: string;
                emailConfiguration: string;
                serviceOverview: string;
                serviceManageInformation: string;
                serviceManageAllUsers: string;
                serviceManageAllUsersAdd: string;
                serviceAdd: string;
            };
        };
        patient: {
            index: string;
            patientNotifications: string;
        };
        messages: {
            inbox: string;
            sent: string;
            newMessage: string;
            messageThread: string;
        };
        nhsappold: {
            index: string;
            viewAppointment: string;
            appointmentOverview: string;
            bookingAppointment: string;
            chooseAppointment: string;
            selectClinic: string;
            appointmentforRefferal: string;
            appointmentBooked: string;
            manageAppointment: string;
            nhsTerms: string;
            rescheduleAppointment: string;
            askReschedule: string;
            askCancelation: string;
            startReschedule: string;
            reasonforReschedule: string;
            reviewRequest: string;
            appointmentRechedule: string;
            cancelAppointment: string;
            appointmentCancelled: string;
        };
        nhsapp: {
            index: string;
            viewOneAppointment: string;
            requestAppointment: string;
            cancel: {
                preparation: string;
                reason: string;
                review: string;
                confirmation: string;
            };
            reschedule: {
                preparation: string;
                new_date: string;
                reason: string;
                review: string;
                confirmation: string;
            };
        };
        referral: {
            index: string;
            patient: {
                referralOverview: string;
                pending: string;
                draft: string;
                submitted: string;
            };
            admin: {
                referralAdmin: string;
                archivedReferral: string;
                serviceAdmin: string;
            };
        };
    };
};

declare class VoiceCommandManager {
    private commands;
    private lastExecutedCommand;
    private receivedCommands;
    constructor();
    addCommand(command: string, action: () => void | Promise<void>): void;
    setReceivedCommand(command: string): string;
    getReceivedCommand(): string | null;
    executeCommand(command: string): Promise<string>;
    removeCommand(command: string): void;
    getLastExecutedCommand(): string | null;
}
declare const voiceCommandManager: VoiceCommandManager;

export { Account, BottomNav, type BottomNavProps, BurgerMenu, type ButtonProps, HeaderSection, type IBurgerMenu, type ITrustInfo, type IUserInfo, LoaderSVG, type LoaderSVGProps, Logo, type LogoProps, Menu, type MenuItem, type MenuItemProps, NavNotification, PrimaryNav, type PrimaryNavProps, RecordStatus, type RecordStatusProps, Tooltip, type UserProfileInfo, portalUrls, voiceCommandManager };
